-- require fingerPaint library
local fingerPaint = require("fingerPaint")

-- require colorPicker library (not required for fingerPaint library)
local colorPicker = require("colorPicker")

-- require widget library (not required for fingerPaint library)
local widget = require("widget")

-- hide status bar
display.setStatusBar( display.HiddenStatusBar )

-- set variables for various screen positions
local centerX = display.contentCenterX
local centerY = display.contentCenterY
local screenTop = display.screenOriginY
local screenLeft = display.screenOriginX
local screenBottom = display.screenOriginY+display.actualContentHeight
local screenRight = display.screenOriginX+display.actualContentWidth
local screenWidth = screenRight - screenLeft
local screenHeight = screenBottom - screenTop

-- make the screen background tan
display.setDefault("background", 1, .85, .5)

-- create a fingerPaint canvas that is 50% of the screen's size
local canvas = fingerPaint.newCanvas({
	width = screenWidth * .5,
	height = screenHeight * .5
})
canvas.anchorX, canvas.anchorY = .5, 0
canvas.x, canvas.y = centerX, screenTop+40

-- create a button to change canvas size & a function to perform the change
local function resizeCanvas(event)
	if canvas.width <= screenWidth * .51 then
		transition.to(canvas, {width = screenWidth - 80, height = screenHeight * .6})
		event.target:setLabel("shrink canvas")
	elseif canvas.width >= screenWidth - 80 then
		transition.to(canvas, {width = screenWidth * .5, height = screenHeight * .5})
		event.target:setLabel("grow canvas")
	end
end

local changeSize = widget.newButton{
	label = "grow canvas",
	width = 0,
	height = 0,
	fontSize = 40,
	onRelease = resizeCanvas
}
	changeSize.anchorX, changeSize.anchorY = 0, 1
	changeSize.x, changeSize.y = screenLeft + 40, screenBottom - 200


-- create UNDO button
local undo = widget.newButton{
	label = "undo",
	width = 0,
	height = 0,
	fontSize = 40,
	onRelease = canvas.undo
}
	undo.anchorX, undo.anchorY = 0, 1
	undo.x, undo.y = screenLeft + 40, screenBottom - 120
	
--create REDO button
local redo = widget.newButton{
	label = "redo",
	width = 0,
	height = 0,
	fontSize = 40,
	onRelease = canvas.redo
}
	redo.anchorX, redo.anchorY = 0, 1
	redo.x, redo.y = screenLeft + 40, screenBottom - 40

-- create a button to change paint color & a function to handle the colorPicker selection
local function changePaintColor(event)
	local function colorListener(r,g,b,a)
		canvas:setPaintColor(r,g,b,a)
	end
	
	colorPicker.show(colorListener, canvas.paintR, canvas.paintG, canvas.paintB, canvas.paintA)
end
	
local changePaintButton = widget.newButton{
	label = "change paint color",
	width = 0,
	height = 0,
	fontSize = 40,
	onRelease = changePaintColor
}
	changePaintButton.anchorX, changePaintButton.anchorY = 1, 1
	changePaintButton.x, changePaintButton.y = screenRight - 40, screenBottom - 200
	
-- create a button to change canvas color & a function to handle the colorPicker selection
local function changeCanvasColor(event)
	local function colorListener(r,g,b,a)
		canvas:setCanvasColor(r,g,b,a)
	end
	
	colorPicker.show(colorListener, canvas.canvasR, canvas.canvasG, canvas.canvasB, canvas.canvasA)
end
	
local changeCanvasButton = widget.newButton{
	label = "change canvas color",
	width = 0,
	height = 0,
	fontSize = 40,
	onRelease = changeCanvasColor
}
	changeCanvasButton.anchorX, changeCanvasButton.anchorY = 1, 1
	changeCanvasButton.x, changeCanvasButton.y = screenRight - 40, screenBottom - 120

-- create a button to enable/disable drawing & a function to perform the change
local function enableDisable(event)
	if canvas.isActive then
		canvas.isActive = false
		event.target:setLabel("enable painting")
	else
		canvas.isActive = true
		event.target:setLabel("disable painting")
	end
end

local enableDisableButton = widget.newButton{
	label = "disable painting",
	width = 0,
	height = 0,
	fontSize = 40,
	onRelease = enableDisable
}
	enableDisableButton.anchorX, enableDisableButton.anchorY = 1, 1
	enableDisableButton.x, enableDisableButton.y = screenRight - 40, screenBottom - 40